<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output omit-xml-declaration="yes" indent="no" />
	<xsl:param name="bulkTransform" />
	<xsl:param name="timeFormat" />

	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="count( /envelope/message ) &gt; 1">
				<xsl:apply-templates select="/envelope/message[last()]">
					<xsl:with-param name="fromEnvelope" select="'no'" />
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="event">
		<div class="status_container">
		    <div class="status_message">
				<xsl:copy-of select="message/child::node()" />
		    </div>
		    <div class="status_time">
				<xsl:call-template name="short-time">
					<xsl:with-param name="date" select="@occurred" />
				</xsl:call-template>
		    </div>
		</div>
	</xsl:template>

	<xsl:template match="message">
		<xsl:param name="fromEnvelope" />
		<div class="time_consecutive">
			<xsl:call-template name="short-time">
				<xsl:with-param name="date" select="@received" />
			</xsl:call-template>
		</div>
		<xsl:choose>
			<xsl:when test="@action = 'yes'">
				<xsl:variable name="senderClass">
					<xsl:choose>
						<xsl:when test="../sender/@self = 'yes'">
							<xsl:text>sender outgoing</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>sender incoming</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<p class="action">
					<span class="{$senderClass}"><xsl:value-of select="../sender" /></span> 
					<xsl:copy-of select="child::node()" />
				</p>
			</xsl:when>
			<xsl:otherwise>
				<p><xsl:copy-of select="child::node()" /></p>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="not( $bulkTransform = 'yes' ) and $fromEnvelope = 'no'">
			<xsl:processing-instruction name="message">type="subsequent"</xsl:processing-instruction>
			<div id="consecutiveInsert" />
		</xsl:if>
	</xsl:template>

	<xsl:template match="envelope">
		<xsl:variable name="containerClass">
			<xsl:choose>
				<xsl:when test="message[1]/@action = 'yes'">
					<xsl:text>container action</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>container</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="senderClass">
			<xsl:choose>
				<xsl:when test="sender/@self = 'yes'">
					<xsl:text>sender outgoing</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>sender incoming</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<div id="{@id}" class="{$containerClass}">
		    <div class="{$senderClass}">
		    	<xsl:value-of select="sender" />
				<xsl:if test="message[1]/@action = 'yes'">
			        <span><xsl:copy-of select="message[1]/child::node()" /></span>
				</xsl:if>
		    </div>
		    <div class="time_initial">
				<xsl:call-template name="short-time">
					<xsl:with-param name="date" select="message[1]/@received" />
				</xsl:call-template>
		    </div>
		    <div class="buddyicon">
				<xsl:choose>
					<xsl:when test="string-length( sender/@card )">
		     		   <img src="file:///tmp/{sender/@card}.tif" width="32" height="32" alt="" onerror="this.src = 'images/person.tif'" />
					</xsl:when>
					<xsl:otherwise>
		     		   <img src="images/person.tif" width="32" height="32" alt="" />
					</xsl:otherwise>
				</xsl:choose>
		    </div>
		    <div class="message">
				<xsl:choose>
					<xsl:when test="not( message[1]/@action = 'yes' )">
				        <p><xsl:copy-of select="message[1]/child::node()" /></p>
						<xsl:apply-templates select="message[position() &gt; 1]">
							<xsl:with-param name="fromEnvelope" select="'yes'" />
						</xsl:apply-templates>
						<xsl:if test="position() = last()">
							<div id="consecutiveInsert" />
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
				        <p>&#160;</p>
						<xsl:apply-templates select="message[position() &gt; 1]">
							<xsl:with-param name="fromEnvelope" select="'yes'" />
						</xsl:apply-templates>
						<xsl:if test="position() = last()">
							<div id="consecutiveInsert" />
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
		    </div>
		</div>
	</xsl:template>

	<xsl:template name="short-time">
		<xsl:param name="date" /> <!-- YYYY-MM-DD HH:MM:SS +/-HHMM -->
		<xsl:value-of select="substring($date, 12, 2)" />
		<xsl:text>:</xsl:text>
		<xsl:value-of select="substring($date, 15, 2)" />
	</xsl:template>
</xsl:transform>
